bind.array: bind.array: bind two 4d arrays to one 4d array.

View source: R/bind.array.R

bind.arrayR Documentation

bind.array: bind two 4d arrays to one 4d array.

Description

This function is to bind two arrays to one array along the first dimension, which obtained by the GoogleImage2array function.

Usage

bind.array(x, y)

Arguments

x

a list obtained by the GoogleImage2array function.

y

a list obtained by the GoogleImage2array function.

Value

array

Author(s)

Satoshi Kume

Examples


library(EBImage)

# Simple examples
query <- "persian cat"
CatImg <- GoogleImage2array(query)

query <- "Shiba inu"
DogImg <- GoogleImage2array(query)

#bind arrays
Dat <- bind.array(CatImg, DogImg)
str(Dat)




kumeS/GoogleImage2Array documentation built on Aug. 27, 2023, 4:44 a.m.