| bind.array | R Documentation |
This function is to bind two arrays to one array along the first dimension, which obtained by the GoogleImage2array function.
bind.array(x, y)
x |
a list obtained by the GoogleImage2array function. |
y |
a list obtained by the GoogleImage2array function. |
array
Satoshi Kume
library(EBImage)
# Simple examples
query <- "persian cat"
CatImg <- GoogleImage2array(query)
query <- "Shiba inu"
DogImg <- GoogleImage2array(query)
#bind arrays
Dat <- bind.array(CatImg, DogImg)
str(Dat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.